==> driza-unix-0.1.tar.gz: driza-unix-0.1/src/interfaz.py <==
#!/usr/bin/python
# -*- coding: latin-1 -*-
#
#Fichero de interfaces

from qt import *
from qttable import *
import sys
import os
import salida


#Clase base de interfaz
class Interfaz:
	"""Clase genérica de la que heredan los interfaces """
	def __init__(self,config,datos):
		self.config=config
		self.datos=datos

class IOutput(Interfaz):
	"""Interfaz con la Salida.R es solo un intermediario"""

	def __init__(self,config,datos):
		Interfaz.__init__(self,config,datos)

	def exp(self,accion,variables,opciones):
		"""Exportacion de interfaz de datos/salida"""

		# El estudio descriptivo Devuelve los datos en una tabla
		# Aqui se controla la accion que va a realizar
		if accion=="descriptivo":
			sys.path.append("./lib")
			from rpy import *    # Funciones rpy
			media=False
			lvariables = [ x.latin1() for x in variables ] # Sin Qstring
			if opciones["media"]:
				lista= [int(x) for x in self.datos.get_col(lvariables[0])]
				media=r.mean(lista)
			resultado=salida.contenedor()
			listas=[["Estadistico R",""],[lvariables[0],media]]
			tabla=salida.tabla()
			tabla.set(listas)
			resultado.append(tabla)
			return resultado 

class IFile(Interfaz):
	""" Interfaz entre datos y ficheros """

	def __init__(self,config,datos):
		import re
		Interfaz.__init__(self,config,datos)

		#Objetos expresiones regulares, para determinar el tipo de fichero
		self.regexd=re.compile('.*\.dat$')
		self.regexp=re.compile('.*\.pkl$')

	def imp(self,fichero):
		"""Coge los datos de un fichero y los guarda en el objeto dato"""
		#Obtener la extension
		#obtener el tipo a partir de una funcion de la libreria de formatos #PENDIENTE
		archivo = open(fichero, 'r')
		if self.regexd.match(fichero):
			lineas = archivo.readlines()
			#transformar lineas para que se adapte a datos
			listadolineas = [ linea.split() for linea in lineas ]
			regexdat=re.compile('^#DAT')
			regexvar=re.compile('^#VAR')
			tempdat=[] #Objeto temporal para guardar los datos
			
			if not regexdat.match(listadolineas[0][0]):
				print "AQUI VA EXCEPCION"
			i=1
			while not regexvar.match(listadolineas[i][0]):
				tempdat.append(listadolineas[i])
				i+=1
			i+=1
			while i<(len(listadolineas)):
				self.datos.app_var(listadolineas[i][0],listadolineas[i][1],listadolineas[i][2])
				i+=1
			#Metemos los datos en el objeto principal
			for i in tempdat:
				self.datos.app_dat(i)
		elif self.regexp.match(fichero):
			import pickle
			self.datos=pickle.load(archivo) #Devuelve copia... corregir
		archivo.close
		return self.datos #SUPERCHAPUZA. deberia trabajar con el objeto....  pero me devuelve unaa copia?¿
			
			
	def exp(self,fichero):
		"""Guarda el contenido de un objeto dato en un fichero"""

		archivo = open(fichero, 'w')
		if self.regexd.match(fichero):
			archivo.write("#DAT\n")
			for x in range(self.datos.num_dat()):
				cadena=""
				for y in self.datos.get_dat(x):
					cadena+=str(y)+" "
				cadena+="\n"
				archivo.write(cadena)
			archivo.write("#VAR\n")
			for x in range(self.datos.num_var()):
				cadena=""
				for y in range(3):
					cadena+=str(self.datos.get_var(x)[y])+" "
				cadena+="\n"
				archivo.write(cadena)
		elif self.regexp.match(fichero):
			import pickle
			pickle.dump(self.datos,archivo)
		archivo.close()

==> driza-unix-0.2.tar.gz: driza-unix-0.2/src/interfaz.py <==
#!/usr/bin/python
# -*- coding: latin-1 -*-
#
#Fichero de interfaces
#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from qttable import *
import sys
import os
import salida
from rpy import *  


#Clase base de interfaz
class Interfaz:
	"""Clase genérica de la que heredan los interfaces """
	def __init__(self,config,datos):
		self.config=config
		self.datos=datos

class IOutput(Interfaz):
	"""Interfaz con la Salida.R es solo un intermediario"""

	def __init__(self,config,datos):
		Interfaz.__init__(self,config,datos)

	def exp(self,accion,variables,opciones):
		"""Exportacion de interfaz de datos/salida"""
		# El estudio descriptivo Devuelve los datos en una tabla
		# Aqui se controla la accion que va a realizar
		if accion=="descriptivo":
			resultado=salida.descriptivo(opciones["media"],opciones["moda"],opciones["varianza"])
			sys.path.append("./lib")
			media=None
			moda=None
			varianza=None
			lvariables = [ x.latin1() for x in variables ] # Sin Qstring
			i=0
			for variable in lvariables:
				lista=[int(x) for x in self.datos.get_col(lvariables[i])]
				if opciones["media"]:
					media=r.mean(lista)
				if opciones["moda"]:
					moda=r.table(lista) #Mal
					moda=moda[0]
				if opciones["varianza"]:
					varianza=r.var(lista)
				resultado.insertarregistro(lvariables[i],media,moda,varianza)
				i+=1
			return resultado 

class IFile(Interfaz):
	""" Interfaz entre datos y ficheros """

	def __init__(self,config,datos):
		import re
		Interfaz.__init__(self,config,datos)

		#Objetos expresiones regulares, para determinar el tipo de fichero
		self.regexd=re.compile('.*\.dat$')
		self.regexp=re.compile('.*\.pkl$')

	def imp(self,fichero):
		"""Coge los datos de un fichero y los guarda en el objeto dato"""
		#Obtener la extension
		#obtener el tipo a partir de una funcion de la libreria de formatos #PENDIENTE
		archivo = open(fichero, 'r')
		if self.regexd.match(fichero):
			lineas = archivo.readlines()
			#transformar lineas para que se adapte a datos
			listadolineas = [ linea.split() for linea in lineas ]
			regexdat=re.compile('^#DAT')
			regexvar=re.compile('^#VAR')
			tempdat=[] #Objeto temporal para guardar los datos
			
			if not regexdat.match(listadolineas[0][0]):
				print "AQUI VA EXCEPCION"
			i=1
			while not regexvar.match(listadolineas[i][0]):
				tempdat.append(listadolineas[i])
				i+=1
			i+=1
			while i<(len(listadolineas)):
				self.datos.app_var(listadolineas[i][0],listadolineas[i][1],listadolineas[i][2])
				i+=1
			#Metemos los datos en el objeto principal
			for i in tempdat:
				self.datos.app_dat(i)
		elif self.regexp.match(fichero):
			import pickle
			self.datos=pickle.load(archivo) #Devuelve copia... corregir
		archivo.close
		return self.datos #SUPERCHAPUZA. deberia trabajar con el objeto....  pero me devuelve unaa copia?¿
			
			
	def exp(self,fichero):
		"""Guarda el contenido de un objeto dato en un fichero"""

		archivo = open(fichero, 'w')
		if self.regexd.match(fichero):
			archivo.write("#DAT\n")
			for x in range(self.datos.num_dat()):
				cadena=""
				for y in self.datos.get_dat(x):
					cadena+=str(y)+" "
				cadena+="\n"
				archivo.write(cadena)
			archivo.write("#VAR\n")
			for x in range(self.datos.num_var()):
				cadena=""
				for y in range(3):
					cadena+=str(self.datos.get_var(x)[y])+" "
				cadena+="\n"
				archivo.write(cadena)
		elif self.regexp.match(fichero):
			import pickle
			pickle.dump(self.datos,archivo)
		archivo.close()
